==> core-1.0.0.tgz: package/lib/class-names/option-group-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiComponentProps } from '../ui-component-props/ui-component-props';
export const optionGroupLayoutClassNamesConfig = {
    prefix: 'cck-option-group',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-option-group'
            ],
            description: 'It will add to the host element of OptionGroup component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-option-group--disabled'
            ],
            description: 'It will add to the host element of OptionGroup component, the component is disabled'
        },
        label: {
            name: 'Host Element',
            selectors: [
                'cck-option-group--label'
            ],
            description: 'It will add to the label element of OptionGroup component'
        }
    }
};
export function getOptionGroupClassNames(componentProps, uiComponentsConfig) {
    const options = {
        componentName: 'optionGroup',
        componentProps,
        uiComponentsConfig
    };
    validateUiComponentProps(options);
    return {
        host: [
            ...optionGroupLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(optionGroupLayoutClassNamesConfig.prefix, options)
        ],
        disabled: [
            ...optionGroupLayoutClassNamesConfig.elements.disabled.selectors
        ],
        label: [
            ...optionGroupLayoutClassNamesConfig.elements.label.selectors
        ]
    };
}

==> core-1.1.0.tgz: package/lib/class-names/option-group-class-names.js <==
import { getHostClassNames } from './class-names';
import { validateUiBaseComponentProps } from '../ui-component-props/ui-component-props';
export const optionGroupLayoutClassNamesConfig = {
    prefix: 'cck-option-group',
    elements: {
        host: {
            name: 'Host Element',
            selectors: [
                'cck-option-group'
            ],
            description: 'It will add to the host element of OptionGroup component.'
        },
        disabled: {
            name: 'Host Element',
            selectors: [
                'cck-option-group--disabled'
            ],
            description: 'It will add to the host element of OptionGroup component, the component is disabled'
        },
        label: {
            name: 'Host Element',
            selectors: [
                'cck-option-group--label'
            ],
            description: 'It will add to the label element of OptionGroup component'
        }
    }
};
export function getOptionGroupClassNames(componentProps, themeConfig) {
    const options = {
        componentName: 'optionGroup',
        componentProps,
        themeConfig
    };
    validateUiBaseComponentProps(options);
    return {
        host: [
            ...optionGroupLayoutClassNamesConfig.elements.host.selectors,
            ...getHostClassNames(optionGroupLayoutClassNamesConfig.prefix, options)
        ].join(' '),
        disabled: [
            ...optionGroupLayoutClassNamesConfig.elements.disabled.selectors
        ].join(' '),
        label: [
            ...optionGroupLayoutClassNamesConfig.elements.label.selectors
        ].join(' ')
    };
}
